# Generated by Django 2.0.6 on 2018-06-10 07:18

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('advanced_filters', '0002_advancedfilter_created_at'),
    ]

    operations = [
        migrations.AlterField(
            model_name='advancedfilter',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='advancedfilter',
            name='created_by',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='created_advanced_filters', to=settings.AUTH_USER_MODEL, verbose_name='Created by'),
        ),
        migrations.AlterField(
            model_name='advancedfilter',
            name='groups',
            field=models.ManyToManyField(blank=True, to='auth.Group', verbose_name='Groups'),
        ),
        migrations.AlterField(
            model_name='advancedfilter',
            name='title',
            field=models.CharField(max_length=255, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='advancedfilter',
            name='url',
            field=models.CharField(max_length=255, verbose_name='URL'),
        ),
        migrations.AlterField(
            model_name='advancedfilter',
            name='users',
            field=models.ManyToManyField(blank=True, to=settings.AUTH_USER_MODEL, verbose_name='Users'),
        ),
    ]
