#form-group {
	width: 100%;
}

.grp-object-tools li div {
	display: block;
	padding: 4px 15px;
	font-weight: bold;
	-webkit-border-radius: 30px;
	-moz-border-radius: 30px;
	-ms-border-radius: 30px;
	-o-border-radius: 30px;
	border-radius: 30px;
	color: #fff;
	border: 1px solid #777;
	opacity: 1;
	background: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgi…pZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
	background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #999999), color-stop(100%, #888888));
	background: -webkit-linear-gradient(#999999,#888888);
	background: -moz-linear-gradient(#999999,#888888);
	background: -o-linear-gradient(#999999,#888888);
	background: linear-gradient(#999999,#888888);
}

.grp-object-tools li div:hover {
	opacity: 1 !important;
	border: 1px solid #2987a6 !important;
	background: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgi…pZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
	background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #36b0d9), color-stop(100%, #309bbf));
	background: -webkit-linear-gradient(#36b0d9,#309bbf);
	background: -moz-linear-gradient(#36b0d9,#309bbf);
	background: -o-linear-gradient(#36b0d9,#309bbf);
	background: linear-gradient(#36b0d9,#309bbf);
}

.grp-object-tools li div.afilters a {
	display: initial;
	padding: initial;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
	-ms-border-radius: 0;
	-o-border-radius: 0;
	border-radius: 0;
	color: #fff;
	border: none;
	opacity: 1;
	background: transparent;
}
.grp-object-tools li div.afilters a:hover {
	border: none!important;
}
.grp-object-tools li div.afilters a.edit-link, .grp-object-tools li div.afilters a.edit-link:hover {
	border-left: 1px solid #777 !important;
	padding-left: 10px;
	margin-left: 10px;
	opacity: 1;
}

.white-popup {
	position: relative;
	background: #FFF;
	padding: 20px;
	width: auto;
	max-width: 800px;
	margin: 20px auto;
}
.empty-form {
	display: none;
}

.select2-container {
    min-width: 166px;
}